ka-snap1 commented on PR #1063:
URL: https://github.com/apache/dubbo-go-pixiu/pull/1063#issuecomment-6368252873

   <p><strong><span>构建成本明显下降;真实 HTTP 
稳态有小幅改善,但更新窗口没有全面改善。</span></strong></p><p><span>以下为四轮指标的中位数,配置为 
</span><strong><span>32 个后端、10007 槽位、100 
请求/秒</span></strong><span>:</span></p><div><div><div>
   场景 | 指标 | 优化前 | 优化后 | 变化
   -- | -- | -- | -- | --
   
   稳态 | P50 | 2.172 ms | 1.886 ms | 降低 13.2%
   稳态 | P95 | 3.167 ms | 3.092 ms | 降低 2.4%
   稳态 | P99 | 3.699 ms | 3.544 ms | 降低 4.2%
   稳态 | CPU 时间/60秒 | 9.930 s | 9.340 s | 降低 5.9%
   稳态 | 采样峰值 RSS | 80.72 MiB | 78.32 MiB | 降低 3.0%
   更新窗口 | P50 | 2.329 ms | 2.050 ms | 降低 12.0%
   更新窗口 | P99 | 3.566 ms | 3.718 ms | 增加 4.3%
   更新窗口 | CPU 时间/60秒 | 10.590 s | 9.905 s | 降低 6.5%
   更新窗口 | 采样峰值 RSS | 80.77 MiB | 78.06 MiB | 降低 3.4%
   
   </div></div></div>


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: [email protected]

For queries about this service, please contact Infrastructure at:
[email protected]


---------------------------------------------------------------------
To unsubscribe, e-mail: [email protected]
For additional commands, e-mail: [email protected]

Reply via email to